Los Angeles Acting Schools and Coaches | Top Schools & Training Lessons for Actors, Singer, Dancers | Career Tips | Backstage | Backstage
Description: A list of Los Angeles-area stage and film acting schools, teachers, and coaches organized by category and alphabetically.
Keywords: acting classes,acting coaches,acting schools,education

- backstage kids
- backstage university
- auditionupdate

- Like us on Facebook
- Follow us on Twitter
- Messages
- Find Talent
- My Account
  - Edit Profile
  - Messages
  - My Dashboard
  - Job History
  - Account Settings
  - Help
  - Logout
- JOIN
- LOG IN

### Subscribe now to and start applying to auditions!

Resources

# Los Angeles Acting Schools and Coaches

By C. Ryanne Laratonda | Posted Feb. 27, 2014, 5:17 p.m.

- Share:

- acting classes
- acting coaches
- acting schools
- education

To find Los Angeles–area stage and film acting schools, teachers, and coaches, click here to search Backstage's Acting Schools database.

Each of the entries contains the following information, if applicable: name of teacher or school, address, phone and fax numbers, email address and/or website, average number of students per class, whether beginning, intermediate, or advanced students are taught, whether auditing is permitted, whether classes are ongoing or by sessions, any special emphasis used in classes or coaching, whether a work/study program is offered. Descriptions of the class, school, or coaching are provided by the instructor or institution and edited by Backstage.

Also, you can find additional schools and coaches in the Backstage Yellow Pages.

Schools and coaches who have been omitted may contact listings {at} backstage.com regarding inclusion in the Acting Schools database. Schools and coaches can also self-post listings and media-enhanced ads in the Backstage Yellow Pages. Contact Backstage's Advertising Department for additional marketing options.

- Read Also:

- Resources

  New York Acting Schools and Coaches

- Resources

  Acting School and Coach Specialties: Finding the Help You Want

What did you think of this story?
Leave a Facebook Comment: